<?php
/**
 * drvng Elementor Extention
 */

final class Drvng_Elementor_Extension {
	/**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 *
	 * @var string The plugin version.
	 */
	const VERSION = '1.0.0';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.8.2';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '7.0';

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var Drvng_Elementor_Extension The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return Drvng_Elementor_Extension An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {

		add_action( 'plugins_loaded', [ $this, 'init' ] );

	}

	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}

		// Add Plugin actions
		add_action( 'elementor/elements/categories_registered', array( $this, 'add_elementor_widget_categories' ) );
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'init_widgets' ] );
		add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'elementor_assets'] );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'drvngsupport' ),
			'<strong>' . esc_html__( 'drvng Elementor Extension', 'drvngsupport' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'drvngsupport' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'drvngsupport' ),
			'<strong>' . esc_html__( 'drvng Elementor Extension', 'drvngsupport' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'drvngsupport' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'drvngsupport' ),
			'<strong>' . esc_html__( 'drvng Elementor Extension', 'drvngsupport' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'drvngsupport' ) . '</strong>',
			 self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	public function add_elementor_widget_categories( $elements_manager ) {
		$elements_manager->add_category(
			'drvng_category',
			[
				'title' => __( 'drvng', 'drvngsupport' ),
				'icon'  => 'fa fa-plug',
			]
		);
	}

	public function elementor_assets() {
		global $plugin_root;
		wp_enqueue_script( "drvng-elementor-js", $plugin_root . 'assets/public/js/drvng-elementor.js', array( 'jquery' ), time(), true );
	}
	/**
	 * Init Widgets
	 *
	 * Include widgets files
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init_widgets() {
		require_once( __DIR__ . '/widgets/main-slider.php' );
		require_once( __DIR__ . '/widgets/main-slider-two.php' );
		require_once( __DIR__ . '/widgets/about.php' );
		require_once( __DIR__ . '/widgets/about-two.php' );
		require_once( __DIR__ . '/widgets/accordion.php' );
		require_once( __DIR__ . '/widgets/client-logo.php' );
		require_once( __DIR__ . '/widgets/contact-form.php' );
		require_once( __DIR__ . '/widgets/contact-info.php' );
		require_once( __DIR__ . '/widgets/contact-widget.php' );
		require_once( __DIR__ . '/widgets/cta.php' );
		require_once( __DIR__ . '/widgets/cta-two.php' );
		require_once( __DIR__ . '/widgets/funfacts.php' );
		require_once( __DIR__ . '/widgets/faq.php' );
		require_once( __DIR__ . '/widgets/intordoction.php' );
		require_once( __DIR__ . '/widgets/pricing.php' );
		require_once( __DIR__ . '/widgets/project.php' );
		require_once( __DIR__ . '/widgets/experience-two.php' );
		require_once( __DIR__ . '/widgets/course-category-widget.php' );
		require_once( __DIR__ . '/widgets/cta-three.php' );
		require_once( __DIR__ . '/widgets/team.php' );
		require_once( __DIR__ . '/widgets/courses.php' );
		require_once( __DIR__ . '/widgets/courses-two.php' );
		require_once( __DIR__ . '/widgets/404.php' );
		require_once( __DIR__ . '/widgets/courses-three.php' );
		require_once( __DIR__ . '/widgets/whychooseus.php' );
		require_once( __DIR__ . '/widgets/services.php' );
		require_once( __DIR__ . '/widgets/experience.php' );
		require_once( __DIR__ . '/widgets/testimonials.php' );
		require_once( __DIR__ . '/widgets/appointment.php' );
		require_once( __DIR__ . '/widgets/news.php' );
		require_once( __DIR__ . '/widgets/client-logo.php' );
		require_once( __DIR__ . '/widgets/features-two.php' );
		
	}
}

Drvng_Elementor_Extension::instance();
